@@ -8,7 +8,7 @@ use vars qw($VERSION @ISA @EXPORT_OK);
 use Fcntl qw(O_RDONLY);
 use integer;
 
-$VERSION = '0.26';
+$VERSION = '0.27';
 
 require Exporter;
 require DynaLoader;
@@ -110,8 +110,8 @@ sub addfile {
 	return(_addfile($self, $file)) unless ref(\$file) eq 'SCALAR';
 
 	$mode = defined($mode) ? $mode : "";
-	my ($binary, $UNIVERSAL, $BITS, $portable) =
-		map { $_ eq $mode } ("b", "U", "0", "p");
+	my ($binary, $UNIVERSAL, $BITS) =
+		map { $_ eq $mode } ("b", "U", "0");
 
 		## Always interpret "-" to mean STDIN; otherwise use
 		## sysopen to handle full range of POSIX file names
@@ -132,17 +132,10 @@ sub addfile {
 		return($self);
 	}
 
-	binmode(FH) if $binary || $portable || $UNIVERSAL;
+	binmode(FH) if $binary || $UNIVERSAL;
 	if ($UNIVERSAL && _istext(*FH, $file)) {
 		$self->_addfileuniv(*FH);
 	}
-	elsif ($portable && _istext(*FH, $file)) {
-		while (<FH>) {
-			s/\015?\015\012/\012/g;
-			s/\015/\012/g;
-			$self->add($_);
-		}
-	}
 	else { $self->_addfilebin(*FH) }
 	close(FH);
 
@@ -499,8 +492,6 @@ argument to one of the following values:
 
 	"0"	use BITS mode
 
-	"p"	use portable mode (to be deprecated)
-
 The "U" mode is modeled on Python's "Universal Newlines" concept, whereby
 DOS and Mac OS line terminators are converted internally to UNIX newlines
 before processing.  This ensures consistent digest values when working
@@ -508,12 +499,6 @@ simultaneously across multiple file systems.  B<The "U" mode influences
 only text files>, namely those passing Perl's I<-T> test; binary files
 are processed with no translation whatsoever.
 
-The "p" mode differs from "U" only in that it treats "\r\r\n" as a single
-newline, a quirky feature designed to accommodate legacy applications that
-occasionally added an extra carriage return before DOS line terminators.
-The "p" mode will be phased out eventually in favor of the cleaner and
-more well-established Universal Newlines concept.
-
 The BITS mode ("0") interprets the contents of I<$filename> as a logical
 stream of bits, where each ASCII '0' or '1' character represents a 0 or
 1 bit, respectively.  All other characters are ignored.  This provides
